/*
 * Copyright (c) 2008-2012, Piccolo2D project, http://piccolo2d.org
 * Copyright (c) 1998-2008, University of Maryland
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided
 * that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list of conditions
 * and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this list of conditions
 * and the following disclaimer in the documentation and/or other materials provided with the
 * distribution.
 *
 * None of the name of the University of Maryland, the name of the Piccolo2D project, or the names of its
 * contributors may be used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.piccolo2d.nodes;

import java.awt.BasicStroke;
import java.awt.Shape;
import java.awt.Stroke;

import java.awt.geom.Path2D;
import java.awt.geom.Rectangle2D;

/**
 * Unit test for PPath.Float.
 */
public class PPathFloatTest extends AbstractPPathTest {

    /** {@inheritDoc} */
    protected PPath createPathNode() {
        return new PPath.Float();
    }

    public void testNoArgConstructor() {
        assertNotNull(new PPath.Float());
    }

    public void testStrokeConstructor() {
        assertNotNull(new PPath.Float((Stroke) null));
        assertNotNull(new PPath.Float(new BasicStroke(2.0f)));
    }

    public void testShapeConstructor() {
        assertNotNull(new PPath.Float(new Rectangle2D.Float(0.0f, 0.0f, 100.0f, 100.0f)));
    }

    public void testShapeStrokeConstructor() {
        assertNotNull(new PPath.Float(new Rectangle2D.Float(0.0f, 0.0f, 100.0f, 100.0f), null));
        assertNotNull(new PPath.Float(new Rectangle2D.Float(0.0f, 0.0f, 100.0f, 100.0f), new BasicStroke(2.0f)));
    }

    public void testShapeConstructorNullArgument() {
        try {
            new PPath.Float((Shape) null);
            fail("ctr((Shape) null) expected NullPointerException");
        }
        catch (NullPointerException e) {
            // expected
        }
    }

    public void testShapeStrokeConstructorNullArgument() {
        try {
            new PPath.Float((Shape) null, null);
            fail("ctr((Shape) null, ) expected NullPointerException");
        }
        catch (NullPointerException e) {
            // expected
        }
    }

    public void testPathConstructor() {
        assertNotNull(new PPath.Float(new Path2D.Float()));
    }

    public void testPathStrokeConstructor() {
        assertNotNull(new PPath.Float(new Path2D.Float(), null));
        assertNotNull(new PPath.Float(new Path2D.Float(), new BasicStroke(2.0f)));
    }

    public void testPathConstructorNullArgument() {
        try {
            new PPath.Float((Path2D) null);
            fail("ctr((Path2D) null) expected NullPointerException");
        }
        catch (NullPointerException e) {
            // expected
        }
    }

    public void testStrokePathConstructorNullArgument() {
        try {
            new PPath.Float((Path2D) null, null);
            fail("ctr((Path2D) null, ) expected NullPointerException");
        }
        catch (NullPointerException e) {
            // expected
        }
    }
}